@@ -383,8 +383,13 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
         # The pool and lock cannot be pickled
         self.__release_coms()
         state = self.__dict__.copy()
-        del state['__cursors']
-        del state['__engine_lock']
+
+        if state and '__cursors' in state.keys():
+            del state['__cursors']
+
+        if state and '__engine_lock' in state.keys():
+            del state['__engine_lock']
+
         return state
 
     def __setstate__(self, state):
