@@ -173,12 +173,14 @@ class Toolbox(TBoxBase, SQLQueue, LogHandle):
         :return: SQL Engine (Engine is still in queue pool)
         """
 
-        engine = self.__find_engine(sql_config)
-
-        if new_instance or engine is None:
-            self.create_sql_engine_to_pool(sql_config=sql_config, conn_max_pool_size=conn_max_pool_size)
+        if new_instance:
+            engine = None
+        else:
             engine = self.__find_engine(sql_config)
 
+        if engine is None:
+            engine = self.create_sql_engine_to_pool(sql_config=sql_config, conn_max_pool_size=conn_max_pool_size)
+
         return engine
 
     def default_sql_conn(self, new_instance=False, conn_max_pool_size=DEFAULT_CONNECTION_SIZE):
@@ -228,12 +230,14 @@ class Toolbox(TBoxBase, SQLQueue, LogHandle):
             sql_config = SQLConfig(server=self.main_config['SQL_Server'].decrypt(),
                                    database=self.main_config['SQL_Database'].decrypt())
 
-            engine = self.__find_engine(sql_config)
-
-            if new_instance or engine is None:
-                self.create_sql_engine_to_pool(sql_config=sql_config, conn_max_pool_size=conn_max_pool_size)
+            if new_instance:
+                engine = None
+            else:
                 engine = self.__find_engine(sql_config)
 
+            if engine is None:
+                engine = self.create_sql_engine_to_pool(sql_config=sql_config, conn_max_pool_size=conn_max_pool_size)
+
                 if not engine and redo_settings(self.main_config):
                     return self.default_sql_conn()
 
